Package: Polychrome
Title: Qualitative Palettes with Many Colors
Version: 1.5.4
Date: 2025-04-06
Authors@R: c(person(given = "Guy", family = "Brock", role = "aut"),
	    person(given = c("Kevin", "R."), family = "Coombes",
                   role = c("aut", "cre"), email = "krc@silicovore.com"))
Description: Tools for creating, viewing, and assessing qualitative
 palettes with many (20-30 or more) colors. See Coombes and colleagues
 (2019) <doi:10.18637/jss.v090.c01>.
Depends: R (>= 4.4)
Imports: colorspace, scatterplot3d, methods, graphics, grDevices,
        stats, utils
Suggests: RColorBrewer, knitr, rmarkdown, ggplot2
License: Apache License (== 2.0)
LazyLoad: yes
LazyData: no
URL: http://oompa.r-forge.r-project.org/
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2025-04-06 21:14:05 UTC; kevin
Author: Guy Brock [aut],
  Kevin R. Coombes [aut, cre]
Maintainer: Kevin R. Coombes <krc@silicovore.com>
Repository: CRAN
Date/Publication: 2025-04-06 21:50:02 UTC
Built: R 4.6.0; ; 2026-04-26 11:36:34 UTC; unix
