Package: Polychrome
Title: Qualitative Palettes with Many Colors
Version: 1.6.1
Date: 2026-07-06
Authors@R: c(person(given = "Guy", family = "Brock", role = "aut"),
	    person(given = c("Kevin", "R."), family = "Coombes",
                   role = c("aut", "cre"), email = "krc@silicovore.com"))
Description: Tools for creating, viewing, and assessing qualitative
 palettes with many (20-30 or more) colors. See Coombes and colleagues
 (2019) <doi:10.18637/jss.v090.c01>.
Depends: R (>= 4.4)
Imports: colorspace, scatterplot3d, methods, graphics, grDevices,
        stats, utils
Suggests: RColorBrewer, knitr, rmarkdown, ggplot2
License: Apache License (== 2.0)
LazyLoad: yes
LazyData: no
URL: http://oompa.r-forge.r-project.org/
VignetteBuilder: knitr
Author: Guy Brock [aut],
  Kevin R. Coombes [aut, cre]
Maintainer: Kevin R. Coombes <krc@silicovore.com>
Repository: R-Forge
Repository/R-Forge/Project: oompa
Repository/R-Forge/Revision: 708
Repository/R-Forge/DateTimeStamp: 2026-07-06 14:32:48
Date/Publication: 2026-07-06 14:32:48
NeedsCompilation: no
Packaged: 2026-07-06 14:44:13 UTC; rforge
