###
### NAMESPACE
###

## Imported methods
import(colorspace)
import(scatterplot3d)

importFrom("graphics", "barplot", "lines", "mtext", "text", "par", "abline", "image")
importFrom("grDevices", "col2rgb", "colors", "rgb")
importFrom("methods", "as")
importFrom("stats", "dist", "hclust", "rnorm", "runif", "princomp")
importFrom("utils", "data")

## Public functions
export(rancurves, ranpoints, uvscatter, luminance,
       plothc, plotpc, p3d, swatch, swatchHue, swatchLuminance, ranswatch,
       computeDistances, plotDistances, invertColors,
       createPalette,
       colorNames, isccNames, xkcdNames)
export(getLUV)

export(sortByHue, sortByLuminance)

export(colorDeficit)

export(memberPlot)

# public data sets
export(kelly.colors, green.armytage.colors,
       alphabet.colors, glasbey.colors,
       palette36.colors, light.colors, dark.colors,
       sky.colors)

